[DTrace-devel] [PATCH] test: remove unnecessary dependency on /proc/kallmodsyms

Kris Van Hees kris.van.hees at oracle.com
Wed Jul 31 19:01:56 UTC 2024


Signed-off-by: Kris Van Hees <kris.van.hees at oracle.com>
---
 test/unittest/actions/symmod/tst.symmod.sh | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/test/unittest/actions/symmod/tst.symmod.sh b/test/unittest/actions/symmod/tst.symmod.sh
index 340baf53..f34a538d 100755
--- a/test/unittest/actions/symmod/tst.symmod.sh
+++ b/test/unittest/actions/symmod/tst.symmod.sh
@@ -1,15 +1,15 @@
 #!/bin/bash
 #
 # Oracle Linux DTrace.
-# Copyright (c) 2021, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2021, 2024, Oracle and/or its affiliates. All rights reserved.
 # Licensed under the Universal Permissive License v 1.0 as shown at
 # http://oss.oracle.com/licenses/upl.
 #
 
 dtrace=$1
 
-# pick a test symbol from /proc/kallmodsyms
-read ADD NAM MOD <<< `awk '/ksys_write/ {print $1, $4, $5}' /proc/kallmodsyms`
+# pick a test symbol from /proc/kallsyms
+read ADD NAM MOD <<< `awk '/ ksys_write/ {print $1, $3, $4}' /proc/kallsyms`
 
 # a blank module means the module is vmlinux
 if [ x$MOD == x ]; then
-- 
2.45.2




More information about the DTrace-devel mailing list